<?php

namespace Drupal\u3id\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Url;
use Drupal\user\Form\UserPasswordResetForm;

/**
 * Form controller for the user password forms.
 *
 * Users followed the link in the email, now they can enter a new password.
 *
 * @internal
 */
class U3idUserPasswordResetForm extends UserPasswordResetForm {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'u3id_pass_reset';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, ?AccountInterface $user = NULL, $expiration_date = NULL, $timestamp = NULL, $hash = NULL) {
    $form = parent::buildForm($form, $form_state, $user, $expiration_date, $timestamp, $hash);
    // Because UserPasswordResetForm currently does not save needed data in
    // $form_state we cannot use hook_form_alter to change #action.
    $form['#action'] = Url::fromRoute('u3id.reset.login', [
      'u3id' => $user->uuid(),
      'timestamp' => $timestamp,
      'hash' => $hash,
    ])->toString();
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // This form works by submitting the hash and timestamp to the u3id.reset
    // route with a 'login' action.
  }

}
